@@ -137,6 +137,14 @@ extern void			cb_print (
 #endif
 );
 
+extern void			cb_print_pos (
+#if NeedFunctionPrototypes
+   Widget,
+   XtPointer,
+   XtPointer
+#endif
+);
+
 extern void			cb_doPrint (
 #if NeedFunctionPrototypes
    Widget,
@@ -145,6 +153,14 @@ extern void			cb_doPrint (
 #endif
 );
 
+extern void			cb_doPrintPos (
+#if NeedFunctionPrototypes
+   Widget,
+   XtPointer,
+   XtPointer
+#endif
+);
+
 extern void			cb_cancelPrint (
 #if NeedFunctionPrototypes
    Widget,
@@ -193,6 +209,14 @@ extern void			cb_reopen (
 #endif
 );
 
+extern void			cb_savepos (
+#if NeedFunctionPrototypes
+   Widget,
+   XtPointer,
+   XtPointer
+#endif
+);
+
 extern void			cb_redisplay (
 #if NeedFunctionPrototypes
    Widget,
@@ -313,4 +337,5 @@ extern void			cb_cancelQuit (
 #endif
 );
 
+
 #endif /* _GV_CALLBACKS_H_ */
