@@ -38,7 +38,6 @@
 */
 #include "message.h"
 
-#include "ac_config.h"
 #include "config.h"
 
 #include <stdlib.h>
@@ -65,6 +64,9 @@
 #include INC_XAW(Scrollbar.h)
 #include INC_XAW(XawInit.h)
 #include INC_XMU(Editres.h)
+#ifdef HAVE_LIBXINERAMA
+   #include INC_EXT(Xinerama.h)
+#endif
 #include "Aaa.h"
 #include "Button.h"
 #include "Clip.h"
@@ -167,6 +169,7 @@ enum
     INFOSILENT_ARG,
     INFOERRORS_ARG,
     INFOALL_ARG,
+    DEBUG_ARG,
     FULLSCREEN_ARG,
     PRESENTATION_ARG,
     MONOCHROME_ARG,
@@ -213,6 +216,7 @@ static struct option const GNU_longOptions[] =
     {"infoSilent", no_argument, NULL, INFOSILENT_ARG},
     {"infoErrors", no_argument, NULL, INFOERRORS_ARG},
     {"infoAll", no_argument, NULL, INFOALL_ARG},
+    {"debug", no_argument, NULL, DEBUG_ARG},
     {"fullscreen", no_argument, NULL, FULLSCREEN_ARG},
     {"presentation", no_argument, NULL, PRESENTATION_ARG},
     {"monochrome", no_argument, NULL, MONOCHROME_ARG},
@@ -251,8 +255,10 @@ static XtActionsRec actions[] = {
  { "GV_Page"		, action_page			},
  { "GV_Panner"		, action_panner			},
  { "GV_Print"		, action_print			},
+ { "GV_PrintPos", action_print_pos			},
  { "GV_Quit"		, action_quit			},
  { "GV_Reopen"		, action_reopen			},
+ { "GV_SavePos"		, action_savepos			},
  { "GV_Resizing"	, action_autoResize		},
  { "GV_Save"		, action_save			},
  { "GV_SetScale"	, action_setScale		},
@@ -582,6 +588,10 @@ int main(argc, argv)
 	   infoverbose_p = 2;
 	   opt_counter++;
 	   break;
+	 case DEBUG_ARG:
+	   debug_p = 1;
+	   opt_counter++;
+	   break;
 	 case MONOCHROME_ARG:
 	   monochrome_p = 1;
 	   opt_counter++;
@@ -684,6 +694,14 @@ int main(argc, argv)
 
     main_setGhostscriptResources(gv_database);
     main_setInternResource(gv_database,&gv_print_command,"printCommand");
+
+    {    
+       char* tmp_savepos_filename;
+       main_setInternResource(gv_database,&tmp_savepos_filename,"saveposFilename");
+       strcpy(gv_savepos_filename, tmp_savepos_filename);
+       file_translateTildeInPath(gv_savepos_filename);
+    }
+    
     main_setInternResource(gv_database,&gv_uncompress_command,"uncompressCommand");
 
     gv_user_defaults_file = resource_userDefaultsFile();
@@ -881,6 +899,7 @@ int main(argc, argv)
        { &fileMenu,         "menu", NULL ,NULL},
        { &openEntry,        "open", cb_openFile, NULL},
        { &reopenEntry,      "reopen", cb_reopen, NULL},
+       { &saveposEntry,     "savepos", cb_savepos, NULL},
        { &updateEntry,      "update", cb_checkFile, (XtPointer)CHECK_FILE_VERSION },
        { NULL,              "line", NULL, NULL },
        { &printAllEntry,    "printAllPages", cb_print, (XtPointer)PAGE_MODE_ALL},
@@ -1397,6 +1416,11 @@ void main_setGhostscriptResources(db)
   else if (!strcasecmp(s, "Errors")) gv_infoVerbose=1;
   else if (!strcasecmp(s, "All"))    gv_infoVerbose=2;
   else gv_infoVerbose = 1;
+  s = resource_getResource(db,gv_class,gv_name,"xinerama",NULL);
+  if (!strcasecmp(s, "Off"))      gv_xinerama=0;
+  else if (!strcasecmp(s, "On")) gv_xinerama=1;
+  else if (!strcasecmp(s, "Auto"))    gv_xinerama=-1;
+  else gv_xinerama = 0;
   ENDMESSAGE(main_setGhostscriptResources)
 }
 
@@ -1407,10 +1431,57 @@ void main_setGhostscriptResources(db)
 void main_setResolutions(query)
   int query;
 {
+  int checkXinerama = 1;
+  int sizeX, sizeY;
+  float ratio;
+  
   BEGINMESSAGE(main_setResolutions)
   if (query) scale_getScreenSize(gv_display,gv_screen,gv_database,gv_class,gv_name,&gv_screen_width,&gv_screen_height);
-  gv_real_xdpi = 72.0 * 72.0 * (float)gv_screen_width  / (25.4 * WidthOfScreen(gv_screen));
-  gv_real_ydpi = 72.0 * 72.0 * (float)gv_screen_height / (25.4 * HeightOfScreen(gv_screen));
+  
+  if (debug_p) printf("Your detected screen size is: %i mm x %i mm\n", gv_screen_width, gv_screen_height);
+
+  /* Some Xinerama implementations summarize the size over all displays.
+     In this case you must use the summarized resolution, too.
+     
+     Other systems return the size of one (which?) display.
+     In this case you have to ask Xinerama about the size of one display. 
+  */
+  
+  ratio = (float) gv_screen_width / (float) gv_screen_height;
+  if ( ratio >= 2 || ratio < 1 ) /* does not look like a single monitor */
+  {
+     checkXinerama = 0;
+     if (debug_p) printf ("That does not look like a single monitor, as the ratio is %.2f.\n", ratio);
+  }
+  else
+     if (debug_p) printf ("That looks like a single monitor, as the ratio is %.2f.\n", ratio);
+     
+  sizeX = WidthOfScreen(gv_screen);
+  sizeY = HeightOfScreen(gv_screen);
+  if (debug_p) printf("Your detected screen resolution is: %i x %i\n", sizeX, sizeY);
+
+#if HAVE_LIBXINERAMA
+  /* In case we do not have Xinerama at all */
+  if (gv_xinerama == 0)
+     checkXinerama = 0;
+  else if (gv_xinerama == 1)
+     checkXinerama = 1;
+  if (!XineramaIsActive(gv_display))
+     checkXinerama = 0;
+
+  if (checkXinerama)
+  {
+    int num_heads;
+    XineramaScreenInfo *head_info;
+    head_info = (XineramaScreenInfo *) XineramaQueryScreens(gv_display,&num_heads);
+    sizeX = head_info[0].width;
+    sizeY = head_info[0].height;
+    if (debug_p) printf("Xinerama's resolution of screen 0 is: %i x %i\n", sizeX, sizeY);
+  }
+#endif
+
+  gv_real_xdpi = 72.0 * 72.0 * (float)gv_screen_width  / (25.4 * sizeX);
+  gv_real_ydpi = 72.0 * 72.0 * (float)gv_screen_height / (25.4 * sizeY);
   gv_pixel_xdpi = 72.0;
   gv_pixel_ydpi = 72.0;
   IIMESSAGE(gv_screen_width,gv_screen_height)
