@@ -70,6 +70,7 @@ EXTERN float                   gv_pixel_xdpi;
 EXTERN float                   gv_pixel_ydpi;
 EXTERN int                     num_ghosts;             /* number of ghostview widgets active */
 EXTERN FILE                    *gv_psfile;             /* file to display */
+EXTERN char                    gv_savepos_filename[GV_MAX_FILENAME_LENGTH];    /* filename used for savepos */
 EXTERN String                  gv_filename;            /* its filename */
 EXTERN String                  gv_filename_old;        /* previous filename */
 EXTERN String                  gv_filename_dsc;        /* file resulting from PDF->DSC conversion */
@@ -148,6 +149,7 @@ EXTERN String			gv_gs_cmd_conv_pdf;	/* command used to convert a pdf file to ps
 EXTERN int			gv_gs_safer;
 EXTERN int                      gv_gs_quiet;
 EXTERN int			gv_infoVerbose;
+EXTERN int			gv_xinerama;
 EXTERN String                   gv_gs_arguments;
 
 /* if a page is requested but gv is busy the following variable
@@ -173,6 +175,7 @@ EXTERN Widget         fileButton;
 EXTERN Widget            fileMenu;
 EXTERN Widget               openEntry;
 EXTERN Widget               reopenEntry;
+EXTERN Widget               saveposEntry;
 EXTERN Widget               updateEntry;
 EXTERN Widget               printAllEntry;
 EXTERN Widget               printMarkedEntry;
@@ -282,6 +285,7 @@ EXTERN int widgetless_p;
 EXTERN int fullscreen_p;
 EXTERN int quiet_p;
 EXTERN int infoverbose_p;
+EXTERN int debug_p;
 EXTERN int monochrome_p;
 EXTERN int media_p;
 EXTERN char *media_value;
