@@ -338,9 +338,6 @@ resource_buildDatabase (
        resource_putResource (&db, app_name, ".arguments", arguments_value);
      }
   
-  INFMESSAGE(parsing command line)
-    XrmParseCommand(&db,options,XtNumber(options),app_name,argcP,argv);
-
   /* ### style resources ######################## */
   INFMESSAGE(checking for style resources)
     s = resource_getResource(db,app_class,app_name,"style","Style");
@@ -551,8 +548,10 @@ int resource_checkResources(app_name,v,vc)
     if (resource_user_file)   fprintf(stderr,"    %s\n",resource_user_file);
     if (resource_style_file)  fprintf(stderr,"    %s\n",resource_style_file);
     if (resource_ad_file)     fprintf(stderr,"    %s\n",resource_ad_file);
-    fprintf(stderr,"belongs to an older version of gv and can not be used.\n");
+    fprintf(stderr,"belongs to an older version of gv and cannot be used.\n");
     fprintf(stderr,"Please remove or update the outdated file.\n");
+    if (resource_user_file) fprintf(stderr,"Quite probably your ~/.gv is too old.\n");
+    if (resource_user_file) fprintf(stderr,"Running gv-update-userconfig should help\nby removing all incompatible resources.\n");
     r=0;
   }
   ENDMESSAGE(resource_checkResources)
