@@ -40,8 +40,8 @@
 #define  VERSION_APPLIC_CONTEXT	app_con  			/* the Application Context */
 
 char *versionIdentification[] = {
-        "gv 3.6.5",
-        "July 2008",
+        "gv 3.6.5.90",
+        "August 2008",
 	0
 };
 
